@@ -1,6 +1,5 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-
 from __future__ import absolute_import
 
 
@@ -29,13 +28,7 @@ class NoRequestedProtocols(UIException):
         self.requested = requested
         self.found = found
 
-        super(NoRequestedProtocols, self).__init__(
-            "None of the provided protocols (%s) are in "
-            "the current list of accepted protocols (%s)" % (
-                self.found, self.requested
-            )
-        )
+        super().__init__("None of the provided protocols (%s) are in " "the current list of accepted protocols (%s)" % (self.found, self.requested))
 
     def __repr__(self):
-        return "NoRequestedProtocols(requested=%s, found=%s)" % (
-            self.requested, self.found)
+        return "NoRequestedProtocols(requested={}, found={})".format(self.requested, self.found)
