@@ -2,8 +2,12 @@
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
 
-from svtplay_dl.utils.output import ETA, progressbar, output
+import os
+
 from svtplay_dl.fetcher import VideoRetriever
+from svtplay_dl.utils.output import ETA
+from svtplay_dl.utils.output import output
+from svtplay_dl.utils.output import progressbar
 
 
 class HTTP(VideoRetriever):
@@ -13,16 +17,20 @@ class HTTP(VideoRetriever):
 
     def download(self):
         """ Get the stream from HTTP """
-        self.output_extention = "mp4"  # this might be wrong..
+        _, ext = os.path.splitext(self.url)
+        if ext == ".mp3":
+            self.output_extention = "mp3"
+        else:
+            self.output_extention = "mp4"  # this might be wrong..
         data = self.http.request("get", self.url, stream=True)
         try:
-            total_size = data.headers['content-length']
+            total_size = data.headers["content-length"]
         except KeyError:
             total_size = 0
         total_size = int(total_size)
         bytes_so_far = 0
 
-        file_d = output(self.output, self.config, "mp4")
+        file_d = output(self.output, self.config, self.output_extention)
         if file_d is None:
             return
 
@@ -32,7 +40,7 @@ class HTTP(VideoRetriever):
             file_d.write(i)
             if not self.config.get("silent"):
                 eta.update(bytes_so_far)
-                progressbar(total_size, bytes_so_far, ''.join(["ETA: ", str(eta)]))
+                progressbar(total_size, bytes_so_far, "".join(["ETA: ", str(eta)]))
 
         file_d.close()
         self.finished = True
