@@ -1,8 +1,9 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import sys
-import logging
 
-log = logging.getLogger('svtplay_dl')
+import logging
+import sys
+
+log = logging.getLogger("svtplay_dl")
 progress_stream = sys.stderr
