@@ -1,16 +1,20 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
+
 import logging
 import os
+import re
 from urllib.parse import urlparse
-from svtplay_dl.utils.parser import readconfig, setup_defaults, merge
 
-from svtplay_dl.utils.http import download_thumbnails, HTTP
+from svtplay_dl.utils.http import download_thumbnails
+from svtplay_dl.utils.http import HTTP
+from svtplay_dl.utils.parser import merge
+from svtplay_dl.utils.parser import readconfig
+from svtplay_dl.utils.parser import setup_defaults
 
 
-class Service(object):
+class Service:
     supported_domains = []
     supported_domains_re = []
 
@@ -21,20 +25,31 @@ class Service(object):
         self.subtitle = None
         self.cookies = {}
         self.auto_name = None
-        self.output = {"title": None, "season": None, "episode": None, "episodename": None,
-                       "id": None, "service": self.__class__.__name__.lower(),
-                       "tvshow": None, "title_nice": None, "showdescription": None,
-                       "episodedescription": None, "showthumbnailurl": None,
-                       "episodethumbnailurl": None, "publishing_datetime": None}
+        self.output = {
+            "title": None,
+            "season": None,
+            "episode": None,
+            "episodename": None,
+            "id": None,
+            "service": self.__class__.__name__.lower(),
+            "tvshow": None,
+            "title_nice": None,
+            "showdescription": None,
+            "episodedescription": None,
+            "showthumbnailurl": None,
+            "episodethumbnailurl": None,
+            "publishing_datetime": None,
+        }
         if not http:
             self.http = HTTP(config)
         else:
             self.http = http
 
         #  Config
-        if os.path.isfile(config.get("configfile")):
-            self.config = merge(readconfig(setup_defaults(), config.get("configfile"),
-                                           service=self.__class__.__name__.lower()).get_variable(), config.get_variable())
+        if config.get("configfile") and os.path.isfile(config.get("configfile")):
+            self.config = merge(
+                readconfig(setup_defaults(), config.get("configfile"), service=self.__class__.__name__.lower()).get_variable(), config.get_variable()
+            )
         else:
             self.config = config
         logging.debug("service: {}".format(self.__class__.__name__.lower()))
@@ -63,7 +78,7 @@ class Service(object):
             return True
 
         # For every listed domain, try with www.subdomain as well.
-        if urlp.netloc in ['www.' + x for x in cls.supported_domains]:
+        if urlp.netloc in ["www." + x for x in cls.supported_domains]:
             return True
 
         return False
@@ -98,10 +113,11 @@ def opengraph_get(html, prop):
     return match.group(1)
 
 
-class OpenGraphThumbMixin(object):
+class OpenGraphThumbMixin:
     """
     Mix this into the service class to grab thumbnail from OpenGraph properties.
     """
+
     def get_thumbnail(self, options):
         url = opengraph_get(self.get_urldata(), "image")
         if url is None:
@@ -109,10 +125,11 @@ class OpenGraphThumbMixin(object):
         download_thumbnails(options, [(False, url)])
 
 
-class MetadataThumbMixin(object):
+class MetadataThumbMixin:
     """
     Mix this into the service class to grab thumbnail from extracted metadata.
     """
+
     def get_thumbnail(self, options):
         urls = []
         if self.output["showthumbnailurl"] is not None:
@@ -124,7 +141,8 @@ class MetadataThumbMixin(object):
 
 
 class Generic(Service):
-    ''' Videos embed in sites '''
+    """ Videos embed in sites """
+
     def get(self, sites):
         data = self.http.request("get", self.url).text
         match = re.search(r"src=(\"|\')(http://www.svt.se/wd[^\'\"]+)(\"|\')", data)
@@ -185,7 +203,7 @@ class Generic(Service):
             for i in sites:
                 if i.handles(url):
                     return self.url, i(self.config, url)
-        match = re.search('(lemonwhale|lwcdn.com)', data)
+        match = re.search("(lemonwhale|lwcdn.com)", data)
         if match:
             url = "http://lemonwhale.com"
             for i in sites:
@@ -197,7 +215,7 @@ class Generic(Service):
             for i in sites:
                 if i.handles(url):
                     return self.url, i(self.config, self.url)
-        match = re.search('(picsearch_ajax_auth|screen9-ajax-auth)', data)
+        match = re.search("(picsearch_ajax_auth|screen9-ajax-auth)", data)
         if match:
             url = "http://csp.picsearch.com"
             for i in sites:
