@@ -1,18 +1,20 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
+
 import json
-from urllib.parse import urljoin, urlparse, parse_qs
+import logging
+import re
+from urllib.parse import parse_qs
+from urllib.parse import urljoin
+from urllib.parse import urlparse
 
-
-from svtplay_dl.log import log
-from svtplay_dl.service.svtplay import Svtplay
 from svtplay_dl.error import ServiceError
+from svtplay_dl.service.svtplay import Svtplay
 
 
 class Barnkanalen(Svtplay):
-    supported_domains = ['svt.se']
+    supported_domains = ["svt.se"]
     supported_path = "/barnkanalen"
 
     @classmethod
@@ -24,7 +26,7 @@ class Barnkanalen(Svtplay):
             return True
 
         # For every listed domain, try with www. subdomain as well.
-        if urlp.netloc in ['www.' + x for x in cls.supported_domains] and correctpath:
+        if urlp.netloc in ["www." + x for x in cls.supported_domains] and correctpath:
             return True
 
         return False
@@ -43,6 +45,10 @@ class Barnkanalen(Svtplay):
             return
 
         janson = json.loads(match.group(1))["context"]["dispatcher"]["stores"]["ApplicationStateStore"]["data"]
+        if "episodeModel" not in janson["categoryStateCache"]["karaktarer"]:
+            yield ServiceError("No videos found")
+            return
+
         janson["video"] = janson["categoryStateCache"]["karaktarer"]["episodeModel"]
 
         if "title" not in janson["video"]:
@@ -59,21 +65,20 @@ class Barnkanalen(Svtplay):
             vid = janson["video"]["programVersionId"]
         else:
             vid = janson["video"]["id"]
-        res = self.http.get("http://api.svt.se/videoplayer-api/video/{0}".format(vid))
+        res = self.http.get("http://api.svt.se/videoplayer-api/video/{}".format(vid))
         try:
             janson = res.json()
         except json.decoder.JSONDecodeError:
-            yield ServiceError("Can't decode api request: {0}".format(res.request.url))
+            yield ServiceError("Can't decode api request: {}".format(res.request.url))
             return
         videos = self._get_video(janson)
-        for i in videos:
-            yield i
+        yield from videos
 
     def find_all_episodes(self, config):
         videos = []
         match = re.search("__barnplay'] = ({.*});", self.get_urldata())
         if not match:
-            log.error("Couldn't retrieve episode list.")
+            logging.error("Couldn't retrieve episode list.")
             return
         else:
             dataj = json.loads(match.group(1))
@@ -88,7 +93,7 @@ class Barnkanalen(Svtplay):
         episodes = [urljoin("http://www.svt.se", x) for x in videos]
 
         if config.get("all_last") > 0:
-            return episodes[-config.get("all_last"):]
+            return episodes[-config.get("all_last") :]
         return episodes
 
     def videos_to_list(self, lvideos, videos):
