@@ -1,15 +1,17 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
-import json
-import copy
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
+import copy
+import json
+import re
+
 from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 
 
 class Bigbrother(Service, OpenGraphThumbMixin):
@@ -42,10 +44,12 @@ class Bigbrother(Service, OpenGraphThumbMixin):
             return
         videoplayer = match.group(1)
 
-        dataurl = "http://c.brightcove.com/services/viewer/htmlFederated?flashID={0}&playerID={1}&playerKey={2}" \
-                  "&isVid=true&isUI=true&dynamicStreaming=true&@videoPlayer={3}".format(flashid, playerid, playerkey, videoplayer)
+        dataurl = (
+            "http://c.brightcove.com/services/viewer/htmlFederated?flashID={}&playerID={}&playerKey={}"
+            "&isVid=true&isUI=true&dynamicStreaming=true&@videoPlayer={}".format(flashid, playerid, playerkey, videoplayer)
+        )
         data = self.http.request("get", dataurl).content
-        match = re.search(r'experienceJSON = ({.*});', data)
+        match = re.search(r"experienceJSON = ({.*});", data)
         if not match:
             yield ServiceError("Can't find json data")
             return
@@ -58,8 +62,9 @@ class Bigbrother(Service, OpenGraphThumbMixin):
 
         for i in renditions:
             if i["defaultURL"].endswith("f4m"):
-                streams = hdsparse(copy.copy(self.config),
-                                   self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}), i["defaultURL"], output=self.output)
+                streams = hdsparse(
+                    copy.copy(self.config), self.http.request("get", i["defaultURL"], params={"hdcore": "3.7.0"}), i["defaultURL"], output=self.output
+                )
                 for n in list(streams.keys()):
                     yield streams[n]
 
