@@ -1,20 +1,21 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-
 from __future__ import absolute_import
+
+import copy
 import json
 import re
-import copy
 from urllib.parse import urlparse
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
+from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
-from svtplay_dl.error import ServiceError
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 
 
 class Disney(Service, OpenGraphThumbMixin):
-    supported_domains = ['disney.se', 'video.disney.se', 'disneyjunior.disney.se']
+    supported_domains = ["disney.se", "video.disney.se", "disneyjunior.disney.se"]
 
     def get(self):
         parse = urlparse(self.url)
@@ -53,7 +54,7 @@ class Disney(Service, OpenGraphThumbMixin):
             jsondata = json.loads(match.group(1))
             parse = urlparse(self.url)
             if len(parse.fragment) > 0:
-                entry = parse.fragment[parse.fragment.rindex("/") + 1:]
+                entry = parse.fragment[parse.fragment.rindex("/") + 1 :]
                 if entry in jsondata["idlist"]:
                     entryid = jsondata["idlist"][entry]
                 else:
@@ -65,8 +66,10 @@ class Disney(Service, OpenGraphThumbMixin):
                     break
             self.output["title"] = title
 
-            url = "http://cdnapi.kaltura.com/html5/html5lib/v1.9.7.6/mwEmbedFrame.php?&wid={0}&uiconf_id={1}&entry_id={2}" \
-                  "&playerId={3}&forceMobileHTML5=true&urid=1.9.7.6&callback=mwi".format(partnerid, uiconfid, entryid, uniq)
+            url = (
+                "http://cdnapi.kaltura.com/html5/html5lib/v1.9.7.6/mwEmbedFrame.php?&wid={}&uiconf_id={}&entry_id={}"
+                "&playerId={}&forceMobileHTML5=true&urid=1.9.7.6&callback=mwi".format(partnerid, uiconfid, entryid, uniq)
+            )
             data = self.http.request("get", url).text
             match = re.search(r"mwi\(({.*})\);", data)
             jsondata = json.loads(match.group(1))
@@ -77,8 +80,10 @@ class Disney(Service, OpenGraphThumbMixin):
             name = jsondata["entryResult"]["meta"]["name"]
             self.output["title"] = name
 
-            url = "http://cdnapi.kaltura.com/p/{0}/sp/{1}00/playManifest/entryId/{2}/format/applehttp/protocol/http/a.m3u8" \
-                  "?ks={3}&referrer=aHR0cDovL3d3dy5kaXNuZXkuc2U=&".format(partnerid[1:], partnerid[1:], entryid, ks)
+            url = (
+                "http://cdnapi.kaltura.com/p/{}/sp/{}00/playManifest/entryId/{}/format/applehttp/protocol/http/a.m3u8"
+                "?ks={}&referrer=aHR0cDovL3d3dy5kaXNuZXkuc2U=&".format(partnerid[1:], partnerid[1:], entryid, ks)
+            )
             redirect = self.http.check_redirect(url)
             streams = hlsparse(self.config, self.http.request("get", redirect), redirect, output=self.output)
             for n in list(streams.keys()):
