@@ -1,12 +1,14 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
-import copy
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
+import copy
+import re
+
 from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 
 
 class Filmarkivet(Service, OpenGraphThumbMixin):
