@@ -1,20 +1,20 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
+
 import copy
+import re
 from urllib.parse import urlparse
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.error import ServiceError
+from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 from svtplay_dl.subtitle import subtitle
 
 
 class Flowonline(Service, OpenGraphThumbMixin):
-    supported_domains_re = [
-        r'^([a-z]{1,4}\.|www\.)?flowonline\.tv$',
-    ]
+    supported_domains_re = [r"^([a-z]{1,4}\.|www\.)?flowonline\.tv$"]
 
     def get(self):
         match = re.search('iframe src="(/embed/[^"]+)"', self.get_urldata())
@@ -23,7 +23,7 @@ class Flowonline(Service, OpenGraphThumbMixin):
             return
         parse = urlparse(self.url)
 
-        url = "{0}://{1}{2}".format(parse.scheme, parse.netloc, match.group(1))
+        url = "{}://{}{}".format(parse.scheme, parse.netloc, match.group(1))
 
         data = self.http.get(url)
 
