@@ -1,18 +1,19 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
-import json
 
-from svtplay_dl.service import Service
+import json
+import re
+
 from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.service import Service
 from svtplay_dl.utils.text import decode_html_entities
 
 
 class Lemonwhale(Service):
     # lemonwhale.com is just bogus for generic
-    supported_domains = ['vk.se', 'lemonwhale.com']
+    supported_domains = ["vk.se", "lemonwhale.com"]
 
     def get(self):
         vid = self.get_vid()
@@ -29,7 +30,7 @@ class Lemonwhale(Service):
                 for n in list(streams.keys()):
                     yield streams[n]
 
-        url = "http://ljsp.lwcdn.com/web/public/video.json?id={0}&delivery=hls".format(decode_html_entities(vid))
+        url = "http://ljsp.lwcdn.com/web/public/video.json?id={}&delivery=hls".format(decode_html_entities(vid))
         data = self.http.request("get", url).text
         jdata = json.loads(data)
         if "videos" in jdata:
@@ -42,7 +43,7 @@ class Lemonwhale(Service):
         if match:
             return match.group(1)
 
-        match = re.search(r'__INITIAL_STATE__ = ({.*})</script>', self.get_urldata())
+        match = re.search(r"__INITIAL_STATE__ = ({.*})</script>", self.get_urldata())
         if match:
             janson = json.loads(match.group(1))
             vid = janson["content"]["current"]["data"]["templateData"]["pageData"]["video"]["id"]
@@ -57,6 +58,6 @@ class Lemonwhale(Service):
         videos = janson["videos"][0]["media"]["streams"]
         for i in videos:
             if i["name"] == "auto":
-                hls = "{0}{1}".format(janson["videos"][0]["media"]["base"], i["url"])
+                hls = "{}{}".format(janson["videos"][0]["media"]["base"], i["url"])
         streams = hlsparse(self.config, self.http.request("get", hls), hls, output=self.output)
         return streams
