@@ -1,18 +1,18 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-
 from __future__ import absolute_import
-import re
-import json
-import copy
 
-from svtplay_dl.service import Service
-from svtplay_dl.fetcher.http import HTTP
+import copy
+import json
+import re
+
 from svtplay_dl.error import ServiceError
+from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.service import Service
 
 
 class Radioplay(Service):
-    supported_domains = ['radioplay.se']
+    supported_domains = ["radioplay.se"]
 
     def get(self):
         data = self.get_urldata()
