@@ -1,12 +1,13 @@
 from __future__ import absolute_import
-import re
+
 import copy
+import re
+
+from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.fetcher.http import HTTP
-
-
-from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.error import ServiceError
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 
 
 class Riksdagen(Service, OpenGraphThumbMixin):
