@@ -1,18 +1,20 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
+
 import copy
 import json
+import re
 
-from svtplay_dl.service import Service
-from svtplay_dl.fetcher.hls import HLS, hlsparse
-from svtplay_dl.fetcher.http import HTTP
 from svtplay_dl.error import ServiceError
+from svtplay_dl.fetcher.hls import HLS
+from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.service import Service
 
 
 class Ruv(Service):
-    supported_domains = ['ruv.is']
+    supported_domains = ["ruv.is"]
 
     def get(self):
         data = self.get_urldata()
@@ -20,7 +22,7 @@ class Ruv(Service):
         match = re.search(r'"([^"]+geo.php)"', data)
         if match:
             data = self.http.request("get", match.group(1)).content
-            match = re.search(r'punktur=\(([^ ]+)\)', data)
+            match = re.search(r"punktur=\(([^ ]+)\)", data)
             if match:
                 janson = json.loads(match.group(1))
                 self.config.get("live", checklive(janson["result"][1]))
