@@ -1,21 +1,23 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import re
-import json
+
 import copy
-from urllib.parse import urljoin, urlparse
+import json
+import logging
+import re
+from urllib.parse import urljoin
+from urllib.parse import urlparse
 
-
-from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.fetcher.hls import hlsparse
-from svtplay_dl.log import log
 from svtplay_dl.error import ServiceError
+from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 from svtplay_dl.subtitle import subtitle
 
 
 class Urplay(Service, OpenGraphThumbMixin):
-    supported_domains = ['urplay.se', 'ur.se', 'betaplay.ur.se', 'urskola.se']
+    supported_domains = ["urplay.se", "ur.se", "betaplay.ur.se", "urskola.se"]
 
     def get(self):
         data = self.get_urldata()
@@ -48,13 +50,13 @@ class Urplay(Service, OpenGraphThumbMixin):
             lbjson = self.http.request("get", url).text
             lbjson = json.loads(lbjson)
             basedomain = lbjson["redirect"]
-        http = "https://{0}/{1}".format(basedomain, jsondata["file_http"])
+        http = "https://{}/{}".format(basedomain, jsondata["file_http"])
         hd = None
         if len(jsondata["file_http_hd"]) > 0:
-            http_hd = "https://{0}/{1}".format(basedomain, jsondata["file_http_hd"])
-            hls_hd = "{0}{1}".format(http_hd, jsondata["streaming_config"]["http_streaming"]["hls_file"])
+            http_hd = "https://{}/{}".format(basedomain, jsondata["file_http_hd"])
+            hls_hd = "{}{}".format(http_hd, jsondata["streaming_config"]["http_streaming"]["hls_file"])
             hd = True
-        hls = "{0}{1}".format(http, jsondata["streaming_config"]["http_streaming"]["hls_file"])
+        hls = "{}{}".format(http, jsondata["streaming_config"]["http_streaming"]["hls_file"])
         streams = hlsparse(self.config, self.http.request("get", hls), hls, output=self.output)
         for n in list(streams.keys()):
             yield streams[n]
@@ -81,7 +83,7 @@ class Urplay(Service, OpenGraphThumbMixin):
         else:
             match = re.search(r"/program/\d+-(\w+)-", parse.path)
             if not match:
-                log.error("Can't find any videos")
+                logging.error("Can't find any videos")
                 return None
             keyword = match.group(1)
             all_links = re.findall('card-link" href="([^"]+)"', self.get_urldata())
