@@ -1,29 +1,45 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-
 # pylint has issues with urlparse: "some types could not be inferred"
 # pylint: disable=E1103
-
 from __future__ import absolute_import
-import re
-import json
+
 import copy
+import json
+import re
 from urllib.parse import urlparse
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
+from svtplay_dl.error import ServiceError
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 from svtplay_dl.subtitle import subtitle
-from svtplay_dl.error import ServiceError
 
 
 class Viaplay(Service, OpenGraphThumbMixin):
     supported_domains = [
-        'tv3play.se', 'tv6play.se', 'tv8play.se', 'tv10play.se',
-        'tv3play.no', 'tv3play.dk', 'tv6play.no', 'viasat4play.no',
-        'tv3play.ee', 'tv3play.lv', 'tv3play.lt', 'tvplay.lv', 'viagame.com',
-        'juicyplay.se', 'viafree.se', 'viafree.dk', 'viafree.no', 'viafree.fi',
-        'play.tv3.lt', 'tv3play.tv3.ee', 'tvplay.skaties.lv'
+        "tv3play.se",
+        "tv6play.se",
+        "tv8play.se",
+        "tv10play.se",
+        "tv3play.no",
+        "tv3play.dk",
+        "tv6play.no",
+        "viasat4play.no",
+        "tv3play.ee",
+        "tv3play.lv",
+        "tv3play.lt",
+        "tvplay.lv",
+        "viagame.com",
+        "juicyplay.se",
+        "viafree.se",
+        "viafree.dk",
+        "viafree.no",
+        "viafree.fi",
+        "play.tv3.lt",
+        "tv3play.tv3.ee",
+        "tvplay.skaties.lv",
     ]
 
     def _get_video_id(self, url=None):
@@ -42,6 +58,9 @@ class Viaplay(Service, OpenGraphThumbMixin):
         if match:
             return match.group(1)
         match = re.search(r'data-videoid="([0-9]+)', html_data)
+        if match:
+            return match.group(1)
+        match = re.search(r'"mediaGuid":"([0-9]+)"', html_data)
         if match:
             return match.group(1)
 
@@ -65,18 +84,18 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 return None
             if "videoIdOrEpisodeNumber" in jansson:
                 videp = jansson["videoIdOrEpisodeNumber"]
-                match = re.search(r'(\w+)-(\d+)', videp)
+                match = re.search(r"(\w+)-(\d+)", videp)
                 if match:
                     episodenr = match.group(2)
                 else:
                     episodenr = videp
                     clips = True
-                match = re.search(r'(s\w+)-(\d+)', season)
+                match = re.search(r"(s\w+)-(\d+)", season)
                 if match:
                     season = match.group(2)
             else:
                 # sometimes videoIdOrEpisodeNumber does not work.. this is a workaround
-                match = re.search(r'(episode|avsnitt)-(\d+)', self.url)
+                match = re.search(r"(episode|avsnitt)-(\d+)", self.url)
                 if match:
                     episodenr = match.group(2)
                 else:
@@ -100,7 +119,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
                                     return episodenr
 
         parse = urlparse(self.url)
-        match = re.search(r'/\w+/(\d+)', parse.path)
+        match = re.search(r"/\w+/(\d+)", parse.path)
         if match:
             return match.group(1)
         match = re.search(r'iframe src="http://play.juicyplay.se[^\"]+id=(\d+)', html_data)
@@ -119,11 +138,10 @@ class Viaplay(Service, OpenGraphThumbMixin):
         if vid is None:
             if parse.path[:6] == "/sport":
                 result = self._sport()
-                for i in result:
-                    yield i
+                yield from result
                 return
             else:
-                yield ServiceError("Can't find video file for: {0}".format(self.url))
+                yield ServiceError("Can't find video file for: {}".format(self.url))
                 return
 
         data = self._get_video_data(vid)
@@ -142,7 +160,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
         self.output["id"] = vid
         self._autoname(dataj)
 
-        streams = self.http.request("get", "http://playapi.mtgx.tv/v3/videos/stream/{0}".format(vid))
+        streams = self.http.request("get", "http://playapi.mtgx.tv/v3/videos/stream/{}".format(vid))
         if streams.status_code == 403:
             yield ServiceError("Can't play this because the video is geoblocked.")
             return
@@ -173,14 +191,12 @@ class Viaplay(Service, OpenGraphThumbMixin):
         if streamj["streams"]["medium"] and streamj["streams"]["medium"][:7] != "[empty]":
             filename = streamj["streams"]["medium"]
             if ".f4m" in filename:
-                streams = hdsparse(self.config, self.http.request("get", filename, params={"hdcore": "3.7.0"}),
-                                   filename, output=self.output)
+                streams = hdsparse(self.config, self.http.request("get", filename, params={"hdcore": "3.7.0"}), filename, output=self.output)
                 for n in list(streams.keys()):
                     yield streams[n]
 
         if streamj["streams"]["hls"]:
-            streams = hlsparse(self.config, self.http.request("get", streamj["streams"]["hls"]),
-                               streamj["streams"]["hls"], output=self.output)
+            streams = hlsparse(self.config, self.http.request("get", streamj["streams"]["hls"]), streamj["streams"]["hls"], output=self.output)
             for n in list(streams.keys()):
                 yield streams[n]
 
@@ -198,7 +214,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
 
         episodes = self._grab_episodes(config, seasons)
         if config.get("all_last") > 0:
-            return episodes[-config.get("all_last"):]
+            return episodes[-config.get("all_last") :]
         return sorted(episodes)
 
     def _grab_episodes(self, config, seasons):
@@ -207,11 +223,11 @@ class Viaplay(Service, OpenGraphThumbMixin):
         match = re.search(r"(saeson|sasong|sesong)-\d+", urlparse(self.url).path)
         if match:
             if re.search(r"(avsnitt|episode)", urlparse(baseurl).path):
-                baseurl = baseurl[:baseurl.rfind("/")]
-            baseurl = baseurl[:baseurl.rfind("/")]
+                baseurl = baseurl[: baseurl.rfind("/")]
+            baseurl = baseurl[: baseurl.rfind("/")]
 
         for i in seasons:
-            url = "{0}/{1}-{2}".format(baseurl, self._isswe(self.url), i)
+            url = "{}/{}-{}".format(baseurl, self._isswe(self.url), i)
             res = self.http.get(url)
             if res:
                 match = self._conentpage(res.text)
@@ -245,7 +261,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
         return episodes
 
     def _get_video_data(self, vid):
-        url = "http://playapi.mtgx.tv/v3/videos/{0}".format(vid)
+        url = "http://playapi.mtgx.tv/v3/videos/{}".format(vid)
         data = self.http.request("get", url)
         return data
 
@@ -270,12 +286,12 @@ class Viaplay(Service, OpenGraphThumbMixin):
             else:
                 title = dataj["summary"].replace("{} - ".format(dataj["format_title"]), "")
                 if title[-1] == ".":
-                    title = title[:len(title) - 1]  # remove the last dot
+                    title = title[: len(title) - 1]  # remove the last dot
 
         if dataj["type"] == "clip":
             # Removes the show name from the end of the filename
             # e.g. Showname.S0X.title instead of Showname.S07.title-showname
-            match = re.search(r'(.+)-', dataj["title"])
+            match = re.search(r"(.+)-", dataj["title"])
             if match:
                 title = match.group(1)
             else:
@@ -283,7 +299,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
             if "derived_from_id" in dataj:
                 if dataj["derived_from_id"]:
                     parent_id = dataj["derived_from_id"]
-                    parent_episode = self.http.request("get", "http://playapi.mtgx.tv/v3/videos/{0}".format(parent_id))
+                    parent_episode = self.http.request("get", "http://playapi.mtgx.tv/v3/videos/{}".format(parent_id))
                     if parent_episode.status_code != 403:  # if not geoblocked
                         datajparent = json.loads(parent_episode.text)
                         if not season and datajparent["format_position"]["season"] > 0:
@@ -301,12 +317,12 @@ class Viaplay(Service, OpenGraphThumbMixin):
     def _sport(self):
         content = self._conentpage(self.get_urldata())
         if not content:
-            yield ServiceError("Can't find video file for: {0}".format(self.url))
+            yield ServiceError("Can't find video file for: {}".format(self.url))
             return
 
         janson = json.loads(content.group(1))
         if not janson["sportsPlayer"]["currentVideo"]:
-            yield ServiceError("Can't find video file for: {0}".format(self.url))
+            yield ServiceError("Can't find video file for: {}".format(self.url))
             return
 
         self.output["title"] = janson["sportsPlayer"]["currentVideo"]["title"]
@@ -317,8 +333,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
             return
 
         for i in res.json()["embedded"]["prioritizedStreams"]:
-            streams = hlsparse(self.config, self.http.request("get", i["links"]["stream"]["href"]),
-                               i["links"]["stream"]["href"], output=self.output)
+            streams = hlsparse(self.config, self.http.request("get", i["links"]["stream"]["href"]), i["links"]["stream"]["href"], output=self.output)
             if streams:
                 for n in list(streams.keys()):
                     yield streams[n]
