@@ -1,25 +1,26 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
+
+import copy
 import json
 import re
-import copy
 
-from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.fetcher.http import HTTP
 from svtplay_dl.error import ServiceError
-
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.http import HTTP
+from svtplay_dl.service import OpenGraphThumbMixin
+from svtplay_dl.service import Service
 
 
 class Vimeo(Service, OpenGraphThumbMixin):
-    supported_domains = ['vimeo.com']
+    supported_domains = ["vimeo.com"]
 
     def get(self):
         data = self.get_urldata()
 
         match_cfg_url = re.search('data-config-url="([^"]+)" data-fallback-url', data)
-        match_clip_page_cfg = re.search(r'vimeo\.clip_page_config\s*=\s*({.+?});', data)
+        match_clip_page_cfg = re.search(r"vimeo\.clip_page_config\s*=\s*({.+?});", data)
 
         if match_cfg_url:
             player_url = match_cfg_url.group(1).replace("&amp;", "&")
@@ -27,7 +28,7 @@ class Vimeo(Service, OpenGraphThumbMixin):
             page_config = json.loads(match_clip_page_cfg.group(1))
             player_url = page_config["player"]["config_url"]
         else:
-            yield ServiceError("Can't find video file for: {0}".format(self.url))
+            yield ServiceError("Can't find video file for: {}".format(self.url))
             return
 
         player_data = self.http.request("get", player_url).text
