@@ -1,6 +1,7 @@
 import argparse
-import platform
+import logging
 import os
+import platform
 
 from yaml import safe_load
 
@@ -13,7 +14,7 @@ else:
     CONFIGFILE = os.path.expanduser("~/.svtplay-dl.yaml")
 
 
-class Options(object):
+class Options:
     """
     Options used when invoking the script from another Python script.
 
@@ -56,92 +57,122 @@ def parser(version):
     parser = argparse.ArgumentParser(prog="svtplay-dl")
     general = parser.add_argument_group()
 
-    general.add_argument('--version', action='version', version='%(prog)s {0}'.format(version))
+    general.add_argument("--version", action="version", version="%(prog)s {}".format(version))
     general.add_argument("-o", "--output", metavar="output", default=None, help="outputs to the given filename or folder")
-    general.add_argument("--subfolder", action="store_true", default=False,
-                         help="Create a subfolder titled as the show, non-series gets in folder movies")
+    general.add_argument(
+        "--subfolder", action="store_true", default=False, help="Create a subfolder titled as the show, non-series gets in folder movies"
+    )
     general.add_argument("--config", dest="configfile", metavar="configfile", default=CONFIGFILE, help="Specify configuration file")
-    general.add_argument("-f", "--force", action="store_true", dest="force", default=False,
-                         help="overwrite if file exists already")
-    general.add_argument("-r", "--resume", action="store_true", dest="resume", default=False,
-                         help="resume a download (RTMP based ones)")
-    general.add_argument("-l", "--live", action="store_true", dest="live", default=False,
-                         help="enable for live streams (RTMP based ones)")
-    general.add_argument("-c", "--capture_time", default=-1, type=int, metavar="capture_time",
-                         help="define capture time in minutes of a live stream")
+    general.add_argument("-f", "--force", action="store_true", dest="force", default=False, help="overwrite if file exists already")
+    general.add_argument("-r", "--resume", action="store_true", dest="resume", default=False, help="resume a download (RTMP obsolete)")
+    general.add_argument("-l", "--live", action="store_true", dest="live", default=False, help="enable for live streams (RTMP based ones)")
+    general.add_argument("-c", "--capture_time", default=-1, type=int, metavar="capture_time", help="define capture time in minutes of a live stream")
     general.add_argument("-s", "--silent", action="store_true", dest="silent", default=False, help="be less verbose")
-    general.add_argument("--silent-semi", action="store_true", dest="silent_semi", default=False,
-                         help="only show a message when the file is downloaded")
+    general.add_argument(
+        "--silent-semi", action="store_true", dest="silent_semi", default=False, help="only show a message when the file is downloaded"
+    )
     general.add_argument("-u", "--username", default=None, help="username")
     general.add_argument("-p", "--password", default=None, help="password")
-    general.add_argument("-t", "--thumbnail", action="store_true", dest="thumbnail", default=False,
-                         help="download thumbnail from the site if available")
-    general.add_argument("-g", "--get-url", action="store_true", dest="get_url", default=False,
-                         help="do not download any video, but instead print the URL.")
-    general.add_argument("--dont-verify-ssl-cert", action="store_false", dest="ssl_verify", default=True,
-                         help="Don't attempt to verify SSL certificates.")
-    general.add_argument("--http-header", dest="http_headers", default=None, metavar="header1=value;header2=value2",
-                         help="A header to add to each HTTP request.")
-    general.add_argument("--remux", dest="remux", default=False, action="store_true",
-                         help="Remux from one container to mp4 using ffmpeg or avconv")
-    general.add_argument("--exclude", dest="exclude", default=None, metavar="WORD1,WORD2,...",
-                         help="exclude videos with the WORD(s) in the filename. comma separated.")
-    general.add_argument("--after-date", dest="after_date", default=None, metavar="yyyy-MM-dd",
-                         help="only videos published on or after this date")
-    general.add_argument("--proxy", dest="proxy", default=None,
-                         metavar="proxy", help="Use the specified HTTP/HTTPS/SOCKS proxy. To enable experimental "
-                                               "SOCKS proxy, specify a proper scheme. For example "
-                                               "socks5://127.0.0.1:1080/.")
-    general.add_argument("-v", "--verbose", action="store_true", dest="verbose", default=False,
-                         help="explain what is going on")
-    general.add_argument("--nfo", action="store_true", dest="nfo", default=False,
-                         help="create a NFO file")
-
+    general.add_argument(
+        "-t", "--thumbnail", action="store_true", dest="thumbnail", default=False, help="download thumbnail from the site if available"
+    )
+    general.add_argument(
+        "-g", "--get-url", action="store_true", dest="get_url", default=False, help="do not download any video, but instead print the URL."
+    )
+    general.add_argument(
+        "--get-only-episode-url",
+        action="store_true",
+        dest="get_only_episode_url",
+        default=False,
+        help="do not get video URLs, only print the episode URL.",
+    )
+    general.add_argument(
+        "--dont-verify-ssl-cert", action="store_false", dest="ssl_verify", default=True, help="Don't attempt to verify SSL certificates."
+    )
+    general.add_argument(
+        "--http-header", dest="http_headers", default=None, metavar="header1=value;header2=value2", help="A header to add to each HTTP request."
+    )
+    general.add_argument("--remux", dest="remux", default=False, action="store_true", help="Remux from one container to mp4 using ffmpeg or avconv")
+    general.add_argument(
+        "--exclude", dest="exclude", default=None, metavar="WORD1,WORD2,...", help="exclude videos with the WORD(s) in the filename. comma separated."
+    )
+    general.add_argument("--after-date", dest="after_date", default=None, metavar="yyyy-MM-dd", help="only videos published on or after this date")
+    general.add_argument(
+        "--proxy",
+        dest="proxy",
+        default=None,
+        metavar="proxy",
+        help="Use the specified HTTP/HTTPS/SOCKS proxy. To enable experimental "
+        "SOCKS proxy, specify a proper scheme. For example "
+        "socks5://127.0.0.1:1080/.",
+    )
+    general.add_argument("-v", "--verbose", action="store_true", dest="verbose", default=False, help="explain what is going on")
+    general.add_argument("--nfo", action="store_true", dest="nfo", default=False, help="create a NFO file")
+    general.add_argument("--force-nfo", action="store_true", dest="force_nfo", default=False, help="download only NFO if used with --nfo")
     quality = parser.add_argument_group("Quality")
-    quality.add_argument("-q", "--quality", default=0, metavar="quality",
-                         help="choose what format to download based on bitrate / video resolution."
-                              "it will download the best format by default")
-    quality.add_argument("-Q", "--flexible-quality", default=0, metavar="amount", dest="flexibleq",
-                         help="allow given quality (as above) to differ by an amount")
-    quality.add_argument("-P", "--preferred", default=None, metavar="preferred",
-                         help="preferred download method (dash, hls, hds, http or rtmp)")
-    quality.add_argument("--list-quality", dest="list_quality", action="store_true", default=False,
-                         help="list the quality for a video")
-    quality.add_argument("--stream-priority", dest="stream_prio", default=None, metavar="dash,hls,hds,http,rtmp",
-                         help="If two streams have the same quality, choose the one you prefer")
+    quality.add_argument(
+        "-q",
+        "--quality",
+        default=0,
+        metavar="quality",
+        help="choose what format to download based on bitrate / video resolution." "it will download the best format by default",
+    )
+    quality.add_argument(
+        "-Q", "--flexible-quality", default=0, metavar="amount", dest="flexibleq", help="allow given quality (as above) to differ by an amount"
+    )
+    quality.add_argument("-P", "--preferred", default=None, metavar="preferred", help="preferred download method (dash, hls, hds, or http)")
+    quality.add_argument("--list-quality", dest="list_quality", action="store_true", default=False, help="list the quality for a video")
+    quality.add_argument(
+        "--stream-priority",
+        dest="stream_prio",
+        default=None,
+        metavar="dash,hls,hds,http",
+        help="If two streams have the same quality, choose the one you prefer",
+    )
 
     subtitle = parser.add_argument_group("Subtitle")
-    subtitle.add_argument("-S", "--subtitle", action="store_true", dest="subtitle", default=False,
-                          help="download subtitle from the site if available")
-    subtitle.add_argument("-M", "--merge-subtitle", action="store_true", dest="merge_subtitle", default=False,
-                          help="merge subtitle with video/audio file with corresponding ISO639-3 language code."
-                               "this invokes --remux automatically. use with -S for external also.")
-    subtitle.add_argument("--force-subtitle", dest="force_subtitle", default=False, action="store_true",
-                          help="download only subtitle if its used with -S")
-    subtitle.add_argument("--require-subtitle", dest="require_subtitle", default=False, action="store_true",
-                          help="download only if a subtitle is available")
-    subtitle.add_argument("--all-subtitles", dest="get_all_subtitles", default=False, action="store_true",
-                          help="Download all available subtitles for the video")
-    subtitle.add_argument("--raw-subtitles", dest="get_raw_subtitles", default=False, action="store_true",
-                          help="also download the subtitles in their native format")
-    subtitle.add_argument("--convert-subtitle-colors", dest="convert_subtitle_colors", default=False,
-                          action="store_true",
-                          help='converts the color information in subtitles, to <font color=""> tags')
+    subtitle.add_argument(
+        "-S", "--subtitle", action="store_true", dest="subtitle", default=False, help="download subtitle from the site if available"
+    )
+    subtitle.add_argument(
+        "-M",
+        "--merge-subtitle",
+        action="store_true",
+        dest="merge_subtitle",
+        default=False,
+        help="merge subtitle with video/audio file with corresponding ISO639-3 language code."
+        "this invokes --remux automatically. use with -S for external also.",
+    )
+    subtitle.add_argument(
+        "--force-subtitle", dest="force_subtitle", default=False, action="store_true", help="download only subtitle if its used with -S"
+    )
+    subtitle.add_argument(
+        "--require-subtitle", dest="require_subtitle", default=False, action="store_true", help="download only if a subtitle is available"
+    )
+    subtitle.add_argument(
+        "--all-subtitles", dest="get_all_subtitles", default=False, action="store_true", help="Download all available subtitles for the video"
+    )
+    subtitle.add_argument(
+        "--raw-subtitles", dest="get_raw_subtitles", default=False, action="store_true", help="also download the subtitles in their native format"
+    )
+    subtitle.add_argument(
+        "--convert-subtitle-colors",
+        dest="convert_subtitle_colors",
+        default=False,
+        action="store_true",
+        help='converts the color information in subtitles, to <font color=""> tags',
+    )
 
     alleps = parser.add_argument_group("All")
-    alleps.add_argument("-A", "--all-episodes", action="store_true", dest="all_episodes", default=False,
-                        help="try to download all episodes")
-    alleps.add_argument("--all-last", dest="all_last", default=-1, type=int, metavar="NN",
-                        help="get last NN episodes instead of all episodes")
-    alleps.add_argument("--include-clips", dest="include_clips", default=False, action="store_true",
-                        help="include clips from websites when using -A")
+    alleps.add_argument("-A", "--all-episodes", action="store_true", dest="all_episodes", default=False, help="try to download all episodes")
+    alleps.add_argument("--all-last", dest="all_last", default=-1, type=int, metavar="NN", help="get last NN episodes instead of all episodes")
+    alleps.add_argument("--include-clips", dest="include_clips", default=False, action="store_true", help="include clips from websites when using -A")
 
     cmorep = parser.add_argument_group("C More")
-    cmorep.add_argument("--cmore-operatorlist", dest="cmoreoperatorlist", default=False, action="store_true",
-                        help="show operatorlist for cmore")
+    cmorep.add_argument("--cmore-operatorlist", dest="cmoreoperatorlist", default=False, action="store_true", help="show operatorlist for cmore")
     cmorep.add_argument("--cmore-operator", dest="cmoreoperator", default=None, metavar="operator")
 
-    parser.add_argument('urls', nargs="*")
+    parser.add_argument("urls", nargs="*")
     options = parser.parse_args()
 
     return parser, options
@@ -176,12 +207,14 @@ def setup_defaults():
     options.set("preferred", None)
     options.set("verbose", False)
     options.set("nfo", False)
+    options.set("force_nfo", False)
     options.set("output_auto", False)
     options.set("service", None)
     options.set("cookies", None)
     options.set("exclude", None)
     options.set("after_date", None)
     options.set("get_url", False)
+    options.set("get_only_episode_url", False)
     options.set("ssl_verify", True)
     options.set("http_headers", None)
     options.set("stream_prio", None)
@@ -219,9 +252,11 @@ def parsertoconfig(config, parser):
     config.set("preferred", parser.preferred)
     config.set("verbose", parser.verbose)
     config.set("nfo", parser.nfo)
+    config.set("force_nfo", parser.force_nfo)
     config.set("exclude", parser.exclude)
     config.set("after_date", parser.after_date)
     config.set("get_url", parser.get_url)
+    config.set("get_only_episode_url", parser.get_only_episode_url)
     config.set("ssl_verify", parser.ssl_verify)
     config.set("http_headers", parser.http_headers)
     config.set("stream_prio", parser.stream_prio)
@@ -251,6 +286,10 @@ def _special_settings(config):
     if config.get("proxy"):
         config.set("proxy", config.get("proxy").replace("socks5", "socks5h", 1))
         config.set("proxy", dict(http=config.get("proxy"), https=config.get("proxy")))
+
+    if config.get("get_only_episode_url"):
+        config.set("get_url", True)
+
     return config
 
 
@@ -274,9 +313,15 @@ def readconfig(config, configfile, service=None, preset=None):
     global configdata
 
     if configfile and configdata is None:
-        with open(configfile) as fd:
-            data = fd.read()
-            configdata = safe_load(data)
+        try:
+            with open(configfile) as fd:
+                data = fd.read()
+                configdata = safe_load(data)
+        except PermissionError:
+            logging.error("Permission denied while reading config: {}".format(configfile))
+
+    if configdata is None:
+        return config
 
     if "default" in configdata:
         config = merge(config.get_variable(), configdata["default"])
